@@ -1,9 +1,11 @@
-import os
 import base64
-import numpy as np
-import geojson
 import json
+import os
 from typing import List
+
+import geojson
+import numpy as np
+
 from fastlabel import const
 
 
@@ -13,11 +15,19 @@ def base64_encode(file_path: str) -> str:
 
 
 def is_image_supported_ext(file_path: str) -> bool:
-    return file_path.lower().endswith(('.png', '.jpg', '.jpeg'))
+    return file_path.lower().endswith((".png", ".jpg", ".jpeg"))
 
 
 def is_video_supported_ext(file_path: str) -> bool:
-    return file_path.lower().endswith('.mp4')
+    return file_path.lower().endswith(".mp4")
+
+
+def is_text_supported_ext(file_path: str) -> bool:
+    return file_path.lower().endswith(".txt")
+
+
+def is_audio_supported_ext(file_path: str) -> bool:
+    return file_path.lower().endswith((".mp3", ".wav", ".m4a"))
 
 
 def is_image_supported_size(file_path: str) -> bool:
@@ -28,8 +38,16 @@ def is_video_supported_size(file_path: str) -> bool:
     return os.path.getsize(file_path) <= const.SUPPORTED_VIDEO_SIZE
 
 
+def is_text_supported_size(file_path: str) -> bool:
+    return os.path.getsize(file_path) <= const.SUPPORTED_TEXT_SIZE
+
+
+def is_audio_supported_size(file_path: str) -> bool:
+    return os.path.getsize(file_path) <= const.SUPPORTED_AUDIO_SIZE
+
+
 def is_json_ext(file_name: str) -> bool:
-    return file_name.lower().endswith('.json')
+    return file_name.lower().endswith(".json")
 
 
 def get_basename(file_path: str) -> str:
@@ -52,10 +70,8 @@ def reverse_points(points: List[int]) -> List[int]:
     reversed_points = []
     for index, _ in enumerate(points):
         if index % 2 == 0:
-            reversed_points.insert(
-                0, points[index + 1])
-            reversed_points.insert(
-                0, points[index])
+            reversed_points.insert(0, points[index + 1])
+            reversed_points.insert(0, points[index])
     return reversed_points
 
 
@@ -63,20 +79,26 @@ def is_clockwise(points: list) -> bool:
     """
     points: [x1, y1, x2, y2, x3, y3, ... xn, yn]
     Sum over the edges, (x2 − x1)(y2 + y1).
-    If the result is positive the curve is clockwise, if it's negative the curve is counter-clockwise.
+    If the result is positive the curve is clockwise,
+    if it's negative the curve is counter-clockwise.
 
     The above is assumes a normal Cartesian coordinate system.
     HTML5 canvas, use an inverted Y-axis.
     Therefore If the area is negative, the curve is clockwise.
     """
-    points_splitted = [points[idx:idx + 2]
-                                    for idx in range(0, len(points), 2)]
+    points_splitted = [points[idx : idx + 2] for idx in range(0, len(points), 2)]
     polygon_geo = geojson.Polygon(points_splitted)
     coords = np.array(list(geojson.utils.coords(polygon_geo)))
     xs, ys = map(list, zip(*coords))
     xs.append(xs[0])
     ys.append(ys[0])
-    sum_edges = sum((xs[i] - xs[i - 1]) * (ys[i] + ys[i - 1]) for i in range(1, len(points_splitted))) / 2.0
+    sum_edges = (
+        sum(
+            (xs[i] - xs[i - 1]) * (ys[i] + ys[i - 1])
+            for i in range(1, len(points_splitted))
+        )
+        / 2.0
+    )
 
     if sum_edges < 0:
         return True
@@ -86,4 +108,3 @@ def is_clockwise(points: list) -> bool:
 def get_json_length(value) -> int:
     json_str = json.dumps(value)
     return len(json_str)
-
